:orphan:

.. _developer-guide:

Developer Guide 
===============

Usage
-----

:ref:`Starting-and-Stopping-Crossbar`

General
-------


Publish and Subscribe
---------------------


Remote Procedure Calls
----------------------


Specific Usages
---------------


Specific Languages
------------------




